Module inksac::types

source ·

Structs

  • String with the colored text
  • A struct representing various styles that can be applied to a string.
  • A builder struct for constructing a Style instance with various configurations.

Enums

  • Represents the different colors that can be used for text foreground and background styling.