pub trait Stylish {
// Required method
fn styled(self, style: Style) -> ColoredString;
}Expand description
Trait for types that can be styled with a Style
pub trait Stylish {
// Required method
fn styled(self, style: Style) -> ColoredString;
}Trait for types that can be styled with a Style