Struct inksac::types::StyleBuilder
source · pub struct StyleBuilder { /* private fields */ }Expand description
A builder struct for constructing a Style instance with various configurations.
Implementations
sourceimpl StyleBuilder
impl StyleBuilder
sourcepub fn foreground(self, color: Color) -> Self
pub fn foreground(self, color: Color) -> Self
sourcepub fn background(self, color: Color) -> Self
pub fn background(self, color: Color) -> Self
sourcepub fn bold(self) -> Self
pub fn bold(self) -> Self
Sets the bold attribute of the style to true.
Example
use inksac::types::StyleBuilder;
let style = StyleBuilder::default()
.bold()
.build();sourcepub fn dim(self) -> Self
pub fn dim(self) -> Self
Sets the dim attribute of the style to true.
Example
use inksac::types::StyleBuilder;
let style = StyleBuilder::default()
.dim()
.build();sourcepub fn italic(self) -> Self
pub fn italic(self) -> Self
Sets the italic attribute of the style to true.
Example
use inksac::types::StyleBuilder;
let style = StyleBuilder::default()
.italic()
.build();Trait Implementations